======================================
``psyclone.tests.lfric_ref_elem_test``
======================================

.. automodule:: psyclone.tests.lfric_ref_elem_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.lfric_ref_elem_test
